decode_client_batch

Function decode_client_batch 

pub fn decode_client_batch(
    payload: &str,
) -> Result<Vec<ClientEnvelope>, ClientBatchDecodeError>
Errors

Returns an error when the frame exceeds the byte limit, the batch exceeds the envelope limit, the payload is not valid envelope JSON, the route metadata is mixed, or any decoded envelope violates the protocol signaling contract.